# Changelog

## 0.1.0-alpha.3 (2025-04-04)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/seiyeah78/stainless-sample-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#10](https://github.com/seiyeah78/stainless-sample-python/issues/10)) ([656bd03](https://github.com/seiyeah78/stainless-sample-python/commit/656bd038171cbc1168427db808dba0088ee136d4))

## 0.1.0-alpha.2 (2025-04-03)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/seiyeah78/stainless-sample-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/seiyeah78/stainless-sample-python/issues/6)) ([165337d](https://github.com/seiyeah78/stainless-sample-python/commit/165337d1017b271dc2770339bd09d3dcb6aa8e96))
* **api:** update via SDK Studio ([#8](https://github.com/seiyeah78/stainless-sample-python/issues/8)) ([211cbf8](https://github.com/seiyeah78/stainless-sample-python/commit/211cbf8fbbe409dbc4b720611636d34012fe088f))

## 0.1.0-alpha.1 (2025-04-01)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/seiyeah78/stainless-sample-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([6a75e29](https://github.com/seiyeah78/stainless-sample-python/commit/6a75e293b5d264c59d8cd1ab17f7f4a38daf0328))
* **api:** update via SDK Studio ([a33615b](https://github.com/seiyeah78/stainless-sample-python/commit/a33615bfb1a0207a71cb13688fb81b976be3987d))
* **api:** update via SDK Studio ([ab67571](https://github.com/seiyeah78/stainless-sample-python/commit/ab675718f8eaa00fe0daa2bf8c1f9161cc3c5eba))


### Chores

* fix typos ([1083555](https://github.com/seiyeah78/stainless-sample-python/commit/1083555f7afb0138365a98313db7adcedf0c2232))
* go live ([#1](https://github.com/seiyeah78/stainless-sample-python/issues/1)) ([0d14688](https://github.com/seiyeah78/stainless-sample-python/commit/0d1468833d9e9438578b61c8dfbe587552e6d46a))
* go live ([#3](https://github.com/seiyeah78/stainless-sample-python/issues/3)) ([d6a12fb](https://github.com/seiyeah78/stainless-sample-python/commit/d6a12fb0a64bdef8fab17ce3cf2a4820a961f8a3))
* update SDK settings ([#4](https://github.com/seiyeah78/stainless-sample-python/issues/4)) ([98f845d](https://github.com/seiyeah78/stainless-sample-python/commit/98f845d44025142b25def1f6b550f6d4a28cd885))
